@@ -1,9 +1,9 @@
 from typing import Any
-from typing import List
 from typing import Optional
 
 from frinx.common.conductor_enums import RetryLogic
 from frinx.common.conductor_enums import TimeoutPolicy
+from frinx.common.frinx_rest import x_from
 from frinx.common.util import snake_to_camel_case
 from pydantic import BaseModel
 from pydantic import Extra
@@ -25,11 +25,9 @@ class TaskOutput(BaseModel):
         extra = Extra.allow
 
 
-class TaskDefinition(BaseModel):
-    name: str
-    description: str
-    labels: Optional[list[object]] = Field(default=None)
-    rbac: Optional[list[object]] = Field(default=None)
+class BaseTaskdef(BaseModel):
+    name: Optional[str]
+    description: Optional[str]
     owner_app: Optional[str] = Field(default=None)
     create_time: Optional[int] = Field(default=None)
     update_time: Optional[int] = Field(default=None)
@@ -43,7 +41,7 @@ class TaskDefinition(BaseModel):
     retry_logic: Optional[RetryLogic] = Field(default=None)
     retry_delay_seconds: Optional[int] = Field(default=None)
     response_timeout_seconds: Optional[int] = Field(default=None)
-    concurrent_execLimit: Optional[int] = Field(default=None)
+    concurrent_exec_limit: Optional[int] = Field(default=None)
     input_template: Optional[dict[str, Any]] = Field(default=None)
     rate_limit_per_frequency: Optional[int] = Field(default=None)
     rate_limit_frequency_in_seconds: Optional[int] = Field(default=None)
@@ -55,15 +53,26 @@ class TaskDefinition(BaseModel):
     limit_to_thread_count: Optional[int] = Field(default=None)
 
     class Config:
-        # allow_mutation = False
-        # extra = Extra.forbid
+        allow_mutation = False
+        extra = Extra.forbid
         validate_assignment = True
         alias_generator = snake_to_camel_case
         allow_population_by_field_name = True
         # TODO  add validators
 
 
-class DefaultTaskDefinition(BaseModel):
+class TaskDefinition(BaseTaskdef):
+    name: str
+    description: str
+    labels: Optional[list[object]] = Field(default=None)
+    rbac: Optional[list[object]] = Field(default=None)
+
+    class Config:
+        allow_mutation = True
+        extra = Extra.forbid
+
+
+class DefaultTaskDefinition(BaseTaskdef):
     retry_count: int = 0
     timeout_policy: TimeoutPolicy = TimeoutPolicy.ALERT_ONLY
     timeout_seconds: int = 60
@@ -72,8 +81,7 @@ class DefaultTaskDefinition(BaseModel):
     response_timeout_seconds: int = 59
     rate_limit_per_frequency: int = 0
     rate_limit_frequency_in_seconds: int = 5
-    owner_email: str = "x_from"  # TODO import from rest_utils
-    limit_to_thread_count: int = 1
+    owner_email: str = x_from
 
 
 class ConductorWorkerError(Exception):
